package com.ruoyi.system.service.impl.projectV2;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.projectV2.ZsyzShqxXmMapper;
import com.ruoyi.system.domain.projectV2.ZsyzShqxXm;
import com.ruoyi.system.service.projectV2.IZsyzShqxXmService;

/**
 * 招商引资_审核期限_项目Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-02-27
 */
@Service
public class ZsyzShqxXmServiceImpl implements IZsyzShqxXmService 
{
    @Autowired
    private ZsyzShqxXmMapper zsyzShqxXmMapper;

    /**
     * 查询招商引资_审核期限_项目
     * 
     * @param id 招商引资_审核期限_项目主键
     * @return 招商引资_审核期限_项目
     */
    @Override
    public ZsyzShqxXm selectZsyzShqxXmById(Long id)
    {
        return zsyzShqxXmMapper.selectZsyzShqxXmById(id);
    }

    /**
     * 查询招商引资_审核期限_项目列表
     * 
     * @param zsyzShqxXm 招商引资_审核期限_项目
     * @return 招商引资_审核期限_项目
     */
    @Override
    public List<ZsyzShqxXm> selectZsyzShqxXmList(ZsyzShqxXm zsyzShqxXm)
    {
        return zsyzShqxXmMapper.selectZsyzShqxXmList(zsyzShqxXm);
    }

    /**
     * 新增招商引资_审核期限_项目
     * 
     * @param zsyzShqxXm 招商引资_审核期限_项目
     * @return 结果
     */
    @Override
    public int insertZsyzShqxXm(ZsyzShqxXm zsyzShqxXm)
    {
        zsyzShqxXm.setCreateTime(DateUtils.getNowDate());
        return zsyzShqxXmMapper.insertZsyzShqxXm(zsyzShqxXm);
    }

    /**
     * 修改招商引资_审核期限_项目
     * 
     * @param zsyzShqxXm 招商引资_审核期限_项目
     * @return 结果
     */
    @Override
    public int updateZsyzShqxXm(ZsyzShqxXm zsyzShqxXm)
    {
        zsyzShqxXm.setUpdateTime(DateUtils.getNowDate());
        return zsyzShqxXmMapper.updateZsyzShqxXm(zsyzShqxXm);
    }

    /**
     * 批量删除招商引资_审核期限_项目
     * 
     * @param ids 需要删除的招商引资_审核期限_项目主键
     * @return 结果
     */
    @Override
    public int deleteZsyzShqxXmByIds(Long[] ids)
    {
        return zsyzShqxXmMapper.deleteZsyzShqxXmByIds(ids);
    }

    /**
     * 删除招商引资_审核期限_项目信息
     * 
     * @param id 招商引资_审核期限_项目主键
     * @return 结果
     */
    @Override
    public int deleteZsyzShqxXmById(Long id)
    {
        return zsyzShqxXmMapper.deleteZsyzShqxXmById(id);
    }
}
