package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.projectV2.ZsyzShqxXm;
import com.ruoyi.system.service.projectV2.IZsyzShqxXmService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_审核期限_项目Controller
 * 
 * @author ruoyi
 * @date 2023-02-27
 */
@RestController
@RequestMapping("/system/xm")
public class ZsyzShqxXmController extends BaseController
{
    @Autowired
    private IZsyzShqxXmService zsyzShqxXmService;

    /**
     * 查询招商引资_审核期限_项目列表
     */
    @PreAuthorize("@ss.hasPermi('system:xm:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzShqxXm zsyzShqxXm)
    {
        startPage();
        List<ZsyzShqxXm> list = zsyzShqxXmService.selectZsyzShqxXmList(zsyzShqxXm);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_审核期限_项目列表
     */
    @PreAuthorize("@ss.hasPermi('system:xm:export')")
    @Log(title = "招商引资_审核期限_项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzShqxXm zsyzShqxXm)
    {
        List<ZsyzShqxXm> list = zsyzShqxXmService.selectZsyzShqxXmList(zsyzShqxXm);
        ExcelUtil<ZsyzShqxXm> util = new ExcelUtil<ZsyzShqxXm>(ZsyzShqxXm.class);
        util.exportExcel(response, list, "招商引资_审核期限_项目数据");
    }

    /**
     * 获取招商引资_审核期限_项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:xm:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzShqxXmService.selectZsyzShqxXmById(id));
    }

    /**
     * 新增招商引资_审核期限_项目
     */
    @PreAuthorize("@ss.hasPermi('system:xm:add')")
    @Log(title = "招商引资_审核期限_项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzShqxXm zsyzShqxXm)
    {
        return toAjax(zsyzShqxXmService.insertZsyzShqxXm(zsyzShqxXm));
    }

    /**
     * 修改招商引资_审核期限_项目
     */
    @PreAuthorize("@ss.hasPermi('system:xm:edit')")
    @Log(title = "招商引资_审核期限_项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZsyzShqxXm zsyzShqxXm)
    {
        return toAjax(zsyzShqxXmService.updateZsyzShqxXm(zsyzShqxXm));
    }

    /**
     * 删除招商引资_审核期限_项目
     */
    @PreAuthorize("@ss.hasPermi('system:xm:remove')")
    @Log(title = "招商引资_审核期限_项目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzShqxXmService.deleteZsyzShqxXmByIds(ids));
    }
}
